@@ -23,9 +23,9 @@ int main(void)
     {    
       /* Set the analog pin 11 & 12, 
 	 which is used by get_distance() */
-      seasim_fake_analog_input (A0,i);
-      seasim_fake_analog_input (A1,j);
-
+      seasim_set_generic_input(11, i, INPUT);
+      seasim_set_generic_input(12, j, INPUT);
+      
       /*
 	printf ("get_distance()=%.4d  (i:%.4d  j:%.4d  ctr:%.4d)\n", 
 	get_distance(), i, j , ctr++);
